@@ -23,11 +23,8 @@
 #include "kitemlistwidget.h"
 
 #include "kitemlistview.h"
-#include "kitemmodelbase.h"
-
 #include "private/kitemlistselectiontoggle.h"
 
-
 #include <QApplication>
 #include <QPainter>
 #include <QPropertyAnimation>
@@ -42,7 +39,7 @@ KItemListWidgetInformant::~KItemListWidgetInformant()
 }
 
 KItemListWidget::KItemListWidget(KItemListWidgetInformant* informant, QGraphicsItem* parent) :
-    QGraphicsWidget(parent, 0),
+    QGraphicsWidget(parent, nullptr),
     m_informant(informant),
     m_index(-1),
     m_selected(false),
@@ -56,9 +53,9 @@ KItemListWidget::KItemListWidget(KItemListWidgetInformant* informant, QGraphicsI
     m_styleOption(),
     m_siblingsInfo(),
     m_hoverOpacity(0),
-    m_hoverCache(0),
-    m_hoverAnimation(0),
-    m_selectionToggle(0),
+    m_hoverCache(nullptr),
+    m_hoverAnimation(nullptr),
+    m_selectionToggle(nullptr),
     m_editedRole()
 {
 }
@@ -72,7 +69,7 @@ void KItemListWidget::setIndex(int index)
 {
     if (m_index != index) {
         delete m_selectionToggle;
-        m_selectionToggle = 0;
+        m_selectionToggle = nullptr;
 
         if (m_hoverAnimation) {
             m_hoverAnimation->stop();
@@ -179,8 +176,8 @@ QList<QByteArray> KItemListWidget::visibleRoles() const
 
 void KItemListWidget::setColumnWidth(const QByteArray& role, qreal width)
 {
-    if (m_columnWidths.value(role) != width) {
-        const qreal previousWidth = width;
+    const qreal previousWidth = m_columnWidths.value(role);
+    if (previousWidth != width) {
         m_columnWidths.insert(role, width);
         columnWidthChanged(role, width, previousWidth);
         update();
@@ -474,7 +471,7 @@ void KItemListWidget::slotHoverAnimationFinished()
 {
     if (!m_hovered && m_selectionToggle) {
         m_selectionToggle->deleteLater();
-        m_selectionToggle = 0;
+        m_selectionToggle = nullptr;
     }
 }
 
@@ -502,7 +499,7 @@ void KItemListWidget::setHoverOpacity(qreal opacity)
 
     if (m_hoverOpacity <= 0.0) {
         delete m_hoverCache;
-        m_hoverCache = 0;
+        m_hoverCache = nullptr;
     }
 
     update();
@@ -511,7 +508,7 @@ void KItemListWidget::setHoverOpacity(qreal opacity)
 void KItemListWidget::clearHoverCache()
 {
     delete m_hoverCache;
-    m_hoverCache = 0;
+    m_hoverCache = nullptr;
 }
 
 void KItemListWidget::drawItemStyleOption(QPainter* painter, QWidget* widget, QStyle::State styleState)
