@@ -17,12 +17,10 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
  ***************************************************************************/
 
-#include "kitemlistviewlayouter.h"
-
-#include <kitemviews/kitemmodelbase.h>
-#include "kitemlistsizehintresolver.h"
-
 #include "dolphindebug.h"
+#include "kitemlistsizehintresolver.h"
+#include "kitemlistviewlayouter.h"
+#include "kitemviews/kitemmodelbase.h"
 
 // #define KITEMLISTVIEWLAYOUTER_DEBUG
 
@@ -35,7 +33,7 @@ KItemListViewLayouter::KItemListViewLayouter(KItemListSizeHintResolver* sizeHint
     m_itemSize(128, 128),
     m_itemMargin(),
     m_headerHeight(0),
-    m_model(0),
+    m_model(nullptr),
     m_sizeHintResolver(sizeHintResolver),
     m_scrollOffset(0),
     m_maximumScrollOffset(0),
