@@ -21,18 +21,17 @@
 
 #include "dolphin_folderspanelsettings.h"
 #include "dolphin_generalsettings.h"
-#include "treeviewcontextmenu.h"
 #include "foldersitemlistwidget.h"
+#include "global.h"
+#include "kitemviews/kfileitemlistview.h"
+#include "kitemviews/kfileitemmodel.h"
+#include "kitemviews/kitemlistcontainer.h"
+#include "kitemviews/kitemlistcontroller.h"
+#include "kitemviews/kitemlistselectionmanager.h"
+#include "treeviewcontextmenu.h"
+#include "views/draganddrophelper.h"
+#include "views/renamedialog.h"
 
-#include <views/renamedialog.h>
-#include <kitemviews/kitemlistselectionmanager.h>
-#include <kitemviews/kfileitemlistview.h>
-#include <kitemviews/kfileitemlistwidget.h>
-#include <kitemviews/kitemlistcontainer.h>
-#include <kitemviews/kitemlistcontroller.h>
-#include <kitemviews/kfileitemmodel.h>
-
-#include <KFileItem>
 #include <KJobWidgets>
 #include <KJobUiDelegate>
 #include <KIO/CopyJob>
@@ -41,17 +40,11 @@
 
 #include <QApplication>
 #include <QBoxLayout>
-#include <QDropEvent>
 #include <QGraphicsSceneDragDropEvent>
 #include <QGraphicsView>
 #include <QPropertyAnimation>
 #include <QTimer>
 
-#include <views/draganddrophelper.h>
-
-#include "dolphindebug.h"
-#include "global.h"
-
 FoldersPanel::FoldersPanel(QWidget* parent) :
     Panel(parent),
     m_updateCurrentItem(false),
